==> tmdy_dll_0.0.0-031117.zip: TiMidity++-2.12.0-pre1b-031117-0200/interface/soundspec.h <==
/*
    TiMidity++ -- MIDI to WAVE converter and player
    Copyright (C) 1999-2002 Masanao Izumo <mo@goice.co.jp>
    Copyright (C) 1995 Tuukka Toivonen <tt@cgs.fi>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef ___SOUNDSPEC_H_
#define ___SOUNDSPEC_H_

struct _soundspec_ex_t {
timidity_mutex_t  busy;

void (*open_soundspec)(tmdy_struct_ex_t *tmdy_struct);
void (*close_soundspec)(tmdy_struct_ex_t *tmdy_struct);
void (*soundspec_setinterval)(tmdy_struct_ex_t *tmdy_struct, double interval_sec);
void (*soundspec_update_wave)(tmdy_struct_ex_t *tmdy_struct, int32 *buff, int samples);
void (*soundspec_reinit)(tmdy_struct_ex_t *tmdy_struct);

int view_soundspec_flag;
int ctl_speana_flag;

};


soundspec_ex_t* new_soundspec(tmdy_struct_ex_t *tmdy_struct);
void destroy_soundspec(soundspec_ex_t* soundspec);

#endif /* ___SOUNDSPEC_H_ */

==> tmdy_dll_0.0.0-031125.zip: TiMidity++-2.12.0-pre1b-031117-0200/interface/soundspec.h <==
/*
    TiMidity++ -- MIDI to WAVE converter and player
    Copyright (C) 1999-2002 Masanao Izumo <mo@goice.co.jp>
    Copyright (C) 1995 Tuukka Toivonen <tt@cgs.fi>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef ___SOUNDSPEC_H_
#define ___SOUNDSPEC_H_

struct s_soundspec_ex_t {
timidity_mutex_t  busy;

void (*open_soundspec)(tmdy_struct_ex_t *tmdy_struct);
void (*close_soundspec)(tmdy_struct_ex_t *tmdy_struct);
void (*soundspec_setinterval)(tmdy_struct_ex_t *tmdy_struct, double interval_sec);
void (*soundspec_update_wave)(tmdy_struct_ex_t *tmdy_struct, int32 *buff, int samples);
void (*soundspec_reinit)(tmdy_struct_ex_t *tmdy_struct);

int view_soundspec_flag;
int ctl_speana_flag;

};


soundspec_ex_t* new_soundspec(tmdy_struct_ex_t *tmdy_struct);
void destroy_soundspec(soundspec_ex_t* soundspec);

#endif /* ___SOUNDSPEC_H_ */
